.. SImMER documentation master file, created by
   sphinx-quickstart on Sat Feb 22 22:19:42 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to SImMER's documentation!
==================================

.. toctree::
   :maxdepth: 2
   :caption: Getting Started

   pages/about
   pages/installation
   pages/overview
   pages/PHARO_reduction
   pages/Shane_reduction
   pages/plotting
   pages/FAQ

.. toctree::
   :maxdepth: 3
   :caption: For developers

   pages/integrations
   pages/versioning
   pages/contributing

.. toctree::
   :maxdepth: 2
   :caption: Documentation

   source/simmer
